==> nextcloud-23.0.9.tgz: nextcloud/apps/federation/l10n/br.js <==
OC.L10N.register(
    "federation",
    {
    "Added to the list of trusted servers" : "Ouzhpennañ d'ar roll ar servijourienn fiziet",
    "Server is already in the list of trusted servers." : "Er roll ar servijour fiziet eo dija",
    "No server to federate with found" : "Servijour da gevredañ ebet kavet",
    "Could not add server" : "Dibosupl ouzhpennañ ar servijour",
    "Trusted servers" : "Servijourienn fiziet",
    "Federation" : "Kevread",
    "Federation allows you to connect with other trusted servers to exchange the user directory." : "Aotreañ a ra deoc'h ar gevread d'en em genstagañ gant servijrourienn fiziet all evit eskemm teuliadoù.",
    "Federation allows you to connect with other trusted servers to exchange the user directory. For example this will be used to auto-complete external users for federated sharing." : "Aotreañ a ra deoc'h ar gevread d'en em genstagañ gant servijrourienn fiziet all evit eskemm teuliadoù. Da skouer implijet e vo evit klokañ en un doare otomatek implijourienn diavaez evit rannadennoù kevredet.",
    "Federation allows you to connect with other trusted servers to exchange the user directory. For example this will be used to auto-complete external users for federated sharing. It is not necessary to add a server as trusted server in order to create a federated share." : "Aotreañ a ra deoc'h ar gevread d'en em genstagañ gant servijrourienn fiziet all evit eskemm teuliadoù. Da skouer implijet e vo evit klokañ en un doare otomatek implijourienn diavaez evit rannadennoù kevredet. N'eo ket rediet ouzhpennañ ur servijour fiziet evit kroui ur rannadenn kevredet.",
    "+ Add trusted server" : "+ Ouzhpenna ur servijour fiziet",
    "Trusted server" : "Servijour fiziet",
    "Add" : "Ouzhpennañ"
},
"nplurals=5; plural=((n%10 == 1) && (n%100 != 11) && (n%100 !=71) && (n%100 !=91) ? 0 :(n%10 == 2) && (n%100 != 12) && (n%100 !=72) && (n%100 !=92) ? 1 :(n%10 ==3 || n%10==4 || n%10==9) && (n%100 < 10 || n% 100 > 19) && (n%100 < 70 || n%100 > 79) && (n%100 < 90 || n%100 > 99) ? 2 :(n != 0 && n % 1000000 == 0) ? 3 : 4);");

==> nextcloud-28.0.3.tgz: nextcloud/apps/federation/l10n/br.js <==
OC.L10N.register(
    "federation",
    {
    "Added to the list of trusted servers" : "Ouzhpennañ d'ar roll ar servijourienn fiziet",
    "Server is already in the list of trusted servers." : "Er roll ar servijour fiziet eo dija",
    "No server to federate with found" : "Servijour da gevredañ ebet kavet",
    "Could not add server" : "Dibosupl ouzhpennañ ar servijour",
    "Trusted servers" : "Servijourienn fiziet",
    "Federation" : "Kevread",
    "+ Add trusted server" : "+ Ouzhpenna ur servijour fiziet",
    "Trusted server" : "Servijour fiziet",
    "Add" : "Ouzhpennañ",
    "Federation allows you to connect with other trusted servers to exchange the user directory." : "Aotreañ a ra deoc'h ar gevread d'en em genstagañ gant servijrourienn fiziet all evit eskemm teuliadoù.",
    "Federation allows you to connect with other trusted servers to exchange the user directory. For example this will be used to auto-complete external users for federated sharing." : "Aotreañ a ra deoc'h ar gevread d'en em genstagañ gant servijrourienn fiziet all evit eskemm teuliadoù. Da skouer implijet e vo evit klokañ en un doare otomatek implijourienn diavaez evit rannadennoù kevredet.",
    "Federation allows you to connect with other trusted servers to exchange the user directory. For example this will be used to auto-complete external users for federated sharing. It is not necessary to add a server as trusted server in order to create a federated share." : "Aotreañ a ra deoc'h ar gevread d'en em genstagañ gant servijrourienn fiziet all evit eskemm teuliadoù. Da skouer implijet e vo evit klokañ en un doare otomatek implijourienn diavaez evit rannadennoù kevredet. N'eo ket rediet ouzhpennañ ur servijour fiziet evit kroui ur rannadenn kevredet."
},
"nplurals=5; plural=((n%10 == 1) && (n%100 != 11) && (n%100 !=71) && (n%100 !=91) ? 0 :(n%10 == 2) && (n%100 != 12) && (n%100 !=72) && (n%100 !=92) ? 1 :(n%10 ==3 || n%10==4 || n%10==9) && (n%100 < 10 || n% 100 > 19) && (n%100 < 70 || n%100 > 79) && (n%100 < 90 || n%100 > 99) ? 2 :(n != 0 && n % 1000000 == 0) ? 3 : 4);");
